//[mahjong-utils](../../../index.md)/[mahjongutils.hora](../index.md)/[RegularHoraHandPattern](index.md)/[pattern](pattern.md)

# pattern

[common]\
val [pattern](pattern.md): [RegularHandPattern](../../mahjongutils.models.hand/-regular-hand-pattern/index.md)

标准形手牌
